@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
@@ -54,6 +53,7 @@ typedef struct _TrackerStatementDelegate TrackerStatementDelegate;
 typedef struct _TrackerCommitDelegate TrackerCommitDelegate;
 
 struct _TrackerDataUpdateBuffer {
+	/* string -> integer */
 	GHashTable *resource_cache;
 	/* string -> TrackerDataUpdateBufferResource */
 	GHashTable *resources;
@@ -69,7 +69,9 @@ struct _TrackerDataUpdateBufferResource {
 	gboolean fts_updated;
 	/* TrackerProperty -> GValueArray */
 	GHashTable *predicates;
+	/* string -> TrackerDataUpdateBufferTable */
 	GHashTable *tables;
+	/* string */
 	GPtrArray *types;
 };
 
@@ -85,6 +87,7 @@ struct _TrackerDataUpdateBufferTable {
 	gboolean delete_value;
 	gboolean multiple_values;
 	TrackerClass *class;
+	/* TrackerDataUpdateBufferProperty */
 	GArray *properties;
 };
 
@@ -93,8 +96,11 @@ struct _TrackerDataUpdateBufferTable {
 struct _TrackerDataBlankBuffer {
 	GHashTable *table;
 	gchar *subject;
+	/* string */
 	GArray *predicates;
+	/* string */
 	GArray *objects;
+	/* string */
 	GArray *graphs;
 };
 
@@ -119,9 +125,9 @@ static GPtrArray *delete_callbacks = NULL;
 static GPtrArray *commit_callbacks = NULL;
 static GPtrArray *rollback_callbacks = NULL;
 
-void 
+void
 tracker_data_add_commit_statement_callback (TrackerCommitCallback    callback,
-					    gpointer                 user_data)
+                                            gpointer                 user_data)
 {
 	TrackerCommitDelegate *delegate = g_new0 (TrackerCommitDelegate, 1);
 
@@ -137,7 +143,7 @@ tracker_data_add_commit_statement_callback (TrackerCommitCallback    callback,
 
 void
 tracker_data_add_rollback_statement_callback (TrackerCommitCallback    callback,
-					      gpointer                 user_data)
+                                              gpointer                 user_data)
 {
 	TrackerCommitDelegate *delegate = g_new0 (TrackerCommitDelegate, 1);
 
@@ -153,7 +159,7 @@ tracker_data_add_rollback_statement_callback (TrackerCommitCallback    callback,
 
 void
 tracker_data_add_insert_statement_callback (TrackerStatementCallback callback,
-					    gpointer                 user_data)
+                                            gpointer                 user_data)
 {
 	TrackerStatementDelegate *delegate = g_new0 (TrackerStatementDelegate, 1);
 
@@ -167,9 +173,9 @@ tracker_data_add_insert_statement_callback (TrackerStatementCallback callback,
 	g_ptr_array_add (insert_callbacks, delegate);
 }
 
-void 
+void
 tracker_data_add_delete_statement_callback (TrackerStatementCallback callback,
-					    gpointer                 user_data)
+                                            gpointer                 user_data)
 {
 	TrackerStatementDelegate *delegate = g_new0 (TrackerStatementDelegate, 1);
 
@@ -194,7 +200,7 @@ tracker_data_update_get_new_service_id (TrackerDBInterface *iface)
 	TrackerDBInterface *temp_iface;
 	TrackerDBStatement *stmt;
 
-	static guint32	    max = 0;
+	static guint32      max = 0;
 
 	if (G_LIKELY (max != 0)) {
 		return ++max;
@@ -203,7 +209,7 @@ tracker_data_update_get_new_service_id (TrackerDBInterface *iface)
 	temp_iface = tracker_db_manager_get_db_interface ();
 
 	stmt = tracker_db_interface_create_statement (temp_iface,
-	                                             "SELECT MAX(ID) AS A FROM \"rdfs:Resource\"");
+	                                              "SELECT MAX(ID) AS A FROM \"rdfs:Resource\"");
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
 
@@ -222,7 +228,7 @@ tracker_data_update_get_next_modseq (void)
 	TrackerDBCursor    *cursor;
 	TrackerDBInterface *temp_iface;
 	TrackerDBStatement *stmt;
-	static guint32	    max = 0;
+	static guint32      max = 0;
 
 	if (G_LIKELY (max != 0)) {
 		return ++max;
@@ -230,7 +236,7 @@ tracker_data_update_get_next_modseq (void)
 
 	temp_iface = tracker_db_manager_get_db_interface ();
 
-	stmt = tracker_db_interface_create_statement (temp_iface, 
+	stmt = tracker_db_interface_create_statement (temp_iface,
 	                                              "SELECT MAX(\"tracker:modified\") AS A FROM \"rdfs:Resource\"");
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
@@ -275,7 +281,7 @@ cache_table_free (TrackerDataUpdateBufferTable *table)
 
 static TrackerDataUpdateBufferTable *
 cache_ensure_table (const gchar            *table_name,
-		    gboolean                multiple_values)
+                    gboolean                multiple_values)
 {
 	TrackerDataUpdateBufferTable *table;
 
@@ -301,10 +307,10 @@ cache_insert_row (TrackerClass *class)
 
 static void
 cache_insert_value (const gchar            *table_name,
-		    const gchar            *field_name,
-		    GValue                 *value,
-		    gboolean                multiple_values,
-		    gboolean                fts)
+                    const gchar            *field_name,
+                    GValue                 *value,
+                    gboolean                multiple_values,
+                    gboolean                fts)
 {
 	TrackerDataUpdateBufferTable    *table;
 	TrackerDataUpdateBufferProperty  property;
@@ -329,10 +335,10 @@ cache_delete_row (TrackerClass *class)
 
 static void
 cache_delete_value (const gchar            *table_name,
-		    const gchar            *field_name,
-		    GValue                 *value,
-		    gboolean                multiple_values,
-		    gboolean                fts)
+                    const gchar            *field_name,
+                    GValue                 *value,
+                    gboolean                multiple_values,
+                    gboolean                fts)
 {
 	TrackerDataUpdateBufferTable    *table;
 	TrackerDataUpdateBufferProperty  property;
@@ -396,8 +402,8 @@ ensure_resource_id (const gchar *uri)
 
 static void
 statement_bind_gvalue (TrackerDBStatement *stmt,
-		       gint                idx,
-		       const GValue       *value)
+                       gint                idx,
+                       const GValue       *value)
 {
 	switch (G_VALUE_TYPE (value)) {
 	case G_TYPE_STRING:
@@ -436,7 +442,7 @@ tracker_data_resource_buffer_flush (GError **error)
 	if (resource_buffer->new_subject != NULL) {
 		/* change uri of resource */
 		stmt = tracker_db_interface_create_statement (iface,
-			"UPDATE \"rdfs:Resource\" SET Uri = ? WHERE ID = ?");
+		                                              "UPDATE \"rdfs:Resource\" SET Uri = ? WHERE ID = ?");
 		tracker_db_statement_bind_text (stmt, 0, resource_buffer->new_subject);
 		tracker_db_statement_bind_int (stmt, 1, resource_buffer->id);
 		tracker_db_statement_execute (stmt, &actual_error);
@@ -460,14 +466,14 @@ tracker_data_resource_buffer_flush (GError **error)
 				if (table->delete_value) {
 					/* delete rows for multiple value properties */
 					stmt = tracker_db_interface_create_statement (iface,
-						"DELETE FROM \"%s\" WHERE ID = ? AND \"%s\" = ?",
-						table_name,
-						property->name);
+					                                              "DELETE FROM \"%s\" WHERE ID = ? AND \"%s\" = ?",
+					                                              table_name,
+					                                              property->name);
 				} else {
 					stmt = tracker_db_interface_create_statement (iface,
-						"INSERT OR IGNORE INTO \"%s\" (ID, \"%s\") VALUES (?, ?)",
-						table_name,
-						property->name);
+					                                              "INSERT OR IGNORE INTO \"%s\" (ID, \"%s\") VALUES (?, ?)",
+					                                              table_name,
+					                                              property->name);
 				}
 
 				tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
@@ -511,8 +517,8 @@ tracker_data_resource_buffer_flush (GError **error)
 			if (table->insert) {
 				/* ensure we have a row for the subject id */
 				stmt = tracker_db_interface_create_statement (iface,
-					"INSERT OR IGNORE INTO \"%s\" (ID) VALUES (?)",
-					table_name);
+				                                              "INSERT OR IGNORE INTO \"%s\" (ID) VALUES (?)",
+				                                              table_name);
 				tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
 				tracker_db_statement_execute (stmt, &actual_error);
 				g_object_unref (stmt);
@@ -633,7 +639,7 @@ tracker_data_update_buffer_clear (void)
 }
 
 static void
-tracker_data_blank_buffer_flush (void)
+tracker_data_blank_buffer_flush (GError **error)
 {
 	/* end of blank node */
 	gint i, id;
@@ -641,6 +647,7 @@ tracker_data_blank_buffer_flush (void)
 	gchar *blank_uri;
 	const gchar *sha1;
 	GChecksum *checksum;
+	GError *actual_error = NULL;
 
 	subject = blank_buffer.subject;
 	blank_buffer.subject = NULL;
@@ -661,7 +668,7 @@ tracker_data_blank_buffer_flush (void)
 
 	/* generate name based uuid */
 	blank_uri = g_strdup_printf ("urn:uuid:%.8s-%.4s-%.4s-%.4s-%.12s",
-		sha1, sha1 + 8, sha1 + 12, sha1 + 16, sha1 + 20);
+	                             sha1, sha1 + 8, sha1 + 12, sha1 + 16, sha1 + 20);
 
 	id = tracker_data_query_resource_id (blank_uri);
 
@@ -673,7 +680,10 @@ tracker_data_blank_buffer_flush (void)
 			                               blank_uri,
 			                               g_array_index (blank_buffer.predicates, gchar *, i),
 			                               g_array_index (blank_buffer.objects, gchar *, i),
-			                               NULL);
+			                               &actual_error);
+			if (actual_error) {
+				break;
+			}
 		}
 	}
 
@@ -689,6 +699,10 @@ tracker_data_blank_buffer_flush (void)
 
 	g_hash_table_insert (blank_buffer.table, subject, blank_uri);
 	g_checksum_free (checksum);
+
+	if (actual_error) {
+		g_propagate_error (error, actual_error);
+	}
 }
 
 static void
@@ -734,8 +748,8 @@ cache_create_service_decomposed (TrackerClass *cl,
 
 			delegate = g_ptr_array_index (insert_callbacks, n);
 			delegate->callback (graph, resource_buffer->subject,
-			                    RDF_PREFIX "type", class_uri, 
-			                    resource_buffer->types, 
+			                    RDF_PREFIX "type", class_uri,
+			                    resource_buffer->types,
 			                    delegate->user_data);
 		}
 	}
@@ -838,8 +852,8 @@ get_property_values (TrackerProperty *property)
 
 	if (multiple_values) {
 		table_name = g_strdup_printf ("%s_%s",
-			tracker_class_get_name (tracker_property_get_domain (property)),
-			tracker_property_get_name (property));
+		                              tracker_class_get_name (tracker_property_get_domain (property)),
+		                              tracker_property_get_name (property));
 	} else {
 		table_name = g_strdup (tracker_class_get_name (tracker_property_get_domain (property)));
 	}
@@ -854,8 +868,8 @@ get_property_values (TrackerProperty *property)
 
 		/* We use a result_set instead of a cursor here because it's
 		 * possible that otherwise the cursor would remain open during
-		 * the call from delete_resource_description. In future we want 
-		 * to allow having the same query open on multiple cursors, 
+		 * the call from delete_resource_description. In future we want
+		 * to allow having the same query open on multiple cursors,
 		 * right now we don't support this. Which is why this workaround */
 
 		if (result_set) {
@@ -885,7 +899,7 @@ get_old_property_values (TrackerProperty  *property,
                          GError          **error)
 {
 	gboolean            fts;
-	TrackerProperty   **properties, **prop;
+	TrackerProperty   **properties, *prop;
 	GValueArray        *old_values;
 
 	fts = tracker_property_get_fulltext_indexed (property);
@@ -895,27 +909,31 @@ get_old_property_values (TrackerProperty  *property,
 	if (old_values == NULL) {
 		if (!check_property_domain (property)) {
 			g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_CONSTRAINT,
-				     "Subject `%s' is not in domain `%s' of property `%s'",
-				     resource_buffer->subject,
-				     tracker_class_get_name (tracker_property_get_domain (property)),
-				     tracker_property_get_name (property));
+			             "Subject `%s' is not in domain `%s' of property `%s'",
+			             resource_buffer->subject,
+			             tracker_class_get_name (tracker_property_get_domain (property)),
+			             tracker_property_get_name (property));
 			return NULL;
 		}
 
 		if (fts && !resource_buffer->fts_updated && !resource_buffer->create) {
+			guint i, n_props;
+
 			/* first fulltext indexed property to be modified
 			 * retrieve values of all fulltext indexed properties
 			 */
 			tracker_fts_update_init (resource_buffer->id);
 
-			properties = tracker_ontology_get_properties ();
+			properties = tracker_ontology_get_properties (&n_props);
 
-			for (prop = properties; *prop; prop++) {
-				if (tracker_property_get_fulltext_indexed (*prop)
-				    && check_property_domain (*prop)) {
+			for (i = 0; i < n_props; i++) {
+				prop = properties[i];
+
+				if (tracker_property_get_fulltext_indexed (prop)
+				    && check_property_domain (prop)) {
 					gint i;
 
-					old_values = get_property_values (*prop);
+					old_values = get_property_values (prop);
 
 					/* delete old fts entries */
 					for (i = 0; i < old_values->n_values; i++) {
@@ -945,7 +963,7 @@ string_to_gvalue (const gchar         *value,
                   TrackerPropertyType  type,
                   GValue              *gvalue)
 {
-	guint32		    object_id;
+	guint32                     object_id;
 
 	switch (type) {
 	case TRACKER_PROPERTY_TYPE_STRING:
@@ -983,9 +1001,9 @@ string_to_gvalue (const gchar         *value,
 }
 
 static void
-cache_set_metadata_decomposed (TrackerProperty	*property,
-			       const gchar	*value,
-			       GError          **error)
+cache_set_metadata_decomposed (TrackerProperty  *property,
+                               const gchar      *value,
+                               GError          **error)
 {
 	gboolean            multiple_values, fts;
 	gchar              *table_name;
@@ -1007,8 +1025,8 @@ cache_set_metadata_decomposed (TrackerProperty	*property,
 	multiple_values = tracker_property_get_multiple_values (property);
 	if (multiple_values) {
 		table_name = g_strdup_printf ("%s_%s",
-			tracker_class_get_name (tracker_property_get_domain (property)),
-			tracker_property_get_name (property));
+		                              tracker_class_get_name (tracker_property_get_domain (property)),
+		                              tracker_property_get_name (property));
 	} else {
 		table_name = g_strdup (tracker_class_get_name (tracker_property_get_domain (property)));
 	}
@@ -1046,8 +1064,8 @@ cache_set_metadata_decomposed (TrackerProperty	*property,
 
 static void
 delete_metadata_decomposed (TrackerProperty  *property,
-			    const gchar	     *value,
-			    GError          **error)
+                            const gchar              *value,
+                            GError          **error)
 {
 	gboolean            multiple_values, fts;
 	gchar              *table_name;
@@ -1060,8 +1078,8 @@ delete_metadata_decomposed (TrackerProperty  *property,
 	multiple_values = tracker_property_get_multiple_values (property);
 	if (multiple_values) {
 		table_name = g_strdup_printf ("%s_%s",
-			tracker_class_get_name (tracker_property_get_domain (property)),
-			tracker_property_get_name (property));
+		                              tracker_class_get_name (tracker_property_get_domain (property)),
+		                              tracker_property_get_name (property));
 	} else {
 		table_name = g_strdup (tracker_class_get_name (tracker_property_get_domain (property)));
 	}
@@ -1103,9 +1121,10 @@ cache_delete_resource_type (TrackerClass *class,
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
 	TrackerDBResultSet *result_set;
-	TrackerProperty   **properties, **prop;
+	TrackerProperty   **properties, *prop;
 	gboolean            found;
 	gint                i;
+	guint               p, n_props;
 
 	iface = tracker_db_manager_get_db_interface ();
 
@@ -1124,9 +1143,9 @@ cache_delete_resource_type (TrackerClass *class,
 	/* retrieve all subclasses we need to remove from the subject
 	 * before we can remove the class specified as object of the statement */
 	stmt = tracker_db_interface_create_statement (iface,
-		"SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:Class_rdfs:subClassOf\".ID) "
-		"FROM \"rdfs:Resource_rdf:type\" INNER JOIN \"rdfs:Class_rdfs:subClassOf\" ON (\"rdf:type\" = \"rdfs:Class_rdfs:subClassOf\".ID) "
-		"WHERE \"rdfs:Resource_rdf:type\".ID = ? AND \"rdfs:subClassOf\" = (SELECT ID FROM \"rdfs:Resource\" WHERE Uri = ?)");
+	                                              "SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:Class_rdfs:subClassOf\".ID) "
+	                                              "FROM \"rdfs:Resource_rdf:type\" INNER JOIN \"rdfs:Class_rdfs:subClassOf\" ON (\"rdf:type\" = \"rdfs:Class_rdfs:subClassOf\".ID) "
+	                                              "WHERE \"rdfs:Resource_rdf:type\".ID = ? AND \"rdfs:subClassOf\" = (SELECT ID FROM \"rdfs:Resource\" WHERE Uri = ?)");
 	tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
 	tracker_db_statement_bind_text (stmt, 1, tracker_class_get_uri (class));
 	result_set = tracker_db_statement_execute (stmt, NULL);
@@ -1146,32 +1165,34 @@ cache_delete_resource_type (TrackerClass *class,
 
 	/* delete all property values */
 
-	properties = tracker_ontology_get_properties ();
+	properties = tracker_ontology_get_properties (&n_props);
 
-	for (prop = properties; *prop; prop++) {
+	for (p = 0; p < n_props; p++) {
 		gboolean            multiple_values, fts;
 		gchar              *table_name;
 		const gchar        *field_name;
 		GValueArray        *old_values;
 		gint                i;
 
-		if (tracker_property_get_domain (*prop) != class) {
+		prop = properties[p];
+
+		if (tracker_property_get_domain (prop) != class) {
 			continue;
 		}
 
-		multiple_values = tracker_property_get_multiple_values (*prop);
+		multiple_values = tracker_property_get_multiple_values (prop);
 		if (multiple_values) {
 			table_name = g_strdup_printf ("%s_%s",
-				tracker_class_get_name (class),
-				tracker_property_get_name (*prop));
+			                              tracker_class_get_name (class),
+			                              tracker_property_get_name (prop));
 		} else {
 			table_name = g_strdup (tracker_class_get_name (class));
 		}
-		field_name = tracker_property_get_name (*prop);
+		field_name = tracker_property_get_name (prop);
 
-		fts = tracker_property_get_fulltext_indexed (*prop);
+		fts = tracker_property_get_fulltext_indexed (prop);
 
-		old_values = get_old_property_values (*prop, NULL);
+		old_values = get_old_property_values (prop, NULL);
 
 		for (i = old_values->n_values - 1; i >= 0 ; i--) {
 			GValue *old_gvalue;
@@ -1198,9 +1219,9 @@ cache_delete_resource_type (TrackerClass *class,
 			TrackerStatementDelegate *delegate;
 
 			delegate = g_ptr_array_index (delete_callbacks, n);
-			delegate->callback (graph, resource_buffer->subject, 
-		                            RDF_PREFIX "type", tracker_class_get_uri (class),
-		                            resource_buffer->types, delegate->user_data);
+			delegate->callback (graph, resource_buffer->subject,
+			                    RDF_PREFIX "type", tracker_class_get_uri (class),
+			                    resource_buffer->types, delegate->user_data);
 		}
 	}
 
@@ -1215,7 +1236,7 @@ tracker_data_delete_statement (const gchar  *graph,
 {
 	TrackerClass       *class;
 	TrackerProperty    *field;
-	gint		    subject_id;
+	gint                subject_id;
 
 	g_return_if_fail (subject != NULL);
 	g_return_if_fail (predicate != NULL);
@@ -1253,7 +1274,7 @@ tracker_data_delete_statement (const gchar  *graph,
 			cache_delete_resource_type (class, graph);
 		} else {
 			g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_UNKNOWN_CLASS,
-				     "Class '%s' not found in the ontology", object);
+			             "Class '%s' not found in the ontology", object);
 		}
 	} else {
 		field = tracker_ontology_get_property_by_uri (predicate);
@@ -1261,7 +1282,7 @@ tracker_data_delete_statement (const gchar  *graph,
 			delete_metadata_decomposed (field, object, error);
 		} else {
 			g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_UNKNOWN_PROPERTY,
-				     "Property '%s' not found in the ontology", predicate);
+			             "Property '%s' not found in the ontology", predicate);
 		}
 
 		if (delete_callbacks) {
@@ -1270,8 +1291,8 @@ tracker_data_delete_statement (const gchar  *graph,
 				TrackerStatementDelegate *delegate;
 
 				delegate = g_ptr_array_index (delete_callbacks, n);
-				delegate->callback (graph, subject, predicate, object, 
-				                    resource_buffer->types, 
+				delegate->callback (graph, subject, predicate, object,
+				                    resource_buffer->types,
 				                    delegate->user_data);
 			}
 		}
@@ -1282,18 +1303,25 @@ static gboolean
 tracker_data_insert_statement_common (const gchar            *graph,
                                       const gchar            *subject,
                                       const gchar            *predicate,
-                                      const gchar            *object)
+                                      const gchar            *object,
+                                      GError                **error)
 {
 	if (g_str_has_prefix (subject, ":")) {
 		/* blank node definition
 		   pile up statements until the end of the blank node */
 		gchar *value;
+		GError *actual_error = NULL;
 
 		if (blank_buffer.subject != NULL) {
 			/* active subject in buffer */
 			if (strcmp (blank_buffer.subject, subject) != 0) {
 				/* subject changed, need to flush buffer */
-				tracker_data_blank_buffer_flush ();
+				tracker_data_blank_buffer_flush (&actual_error);
+
+				if (actual_error) {
+					g_propagate_error (error, actual_error);
+					return FALSE;
+				}
 			}
 		}
 
@@ -1338,7 +1366,7 @@ tracker_data_insert_statement_common (const gchar            *graph,
 		}
 		resource_buffer->predicates = g_hash_table_new_full (g_direct_hash, g_direct_equal, g_object_unref, (GDestroyNotify) g_value_array_free);
 		resource_buffer->tables = g_hash_table_new_full (g_str_hash, g_str_equal,
-							      g_free, (GDestroyNotify) cache_table_free);
+		                                                 g_free, (GDestroyNotify) cache_table_free);
 
 		g_value_set_int (&gvalue, tracker_data_update_get_next_modseq ());
 		cache_insert_value ("rdfs:Resource", "tracker:modified", &gvalue, FALSE, FALSE);
@@ -1400,7 +1428,7 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 			/* virtual tracker:uri property */
 		} else {
 			g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_UNKNOWN_PROPERTY,
-				     "Property '%s' not found in the ontology", predicate);
+			             "Property '%s' not found in the ontology", predicate);
 			return;
 		}
 	} else if (tracker_property_get_data_type (property) != TRACKER_PROPERTY_TYPE_RESOURCE) {
@@ -1417,7 +1445,12 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 		if (blank_buffer.subject != NULL) {
 			if (strcmp (blank_buffer.subject, object) == 0) {
 				/* object still in blank buffer, need to flush buffer */
-				tracker_data_blank_buffer_flush ();
+				tracker_data_blank_buffer_flush (&actual_error);
+
+				if (actual_error) {
+					g_propagate_error (error, actual_error);
+					return;
+				}
 			}
 		}
 
@@ -1425,17 +1458,27 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 
 		if (blank_uri != NULL) {
 			/* now insert statement referring to blank node */
-			tracker_data_insert_statement (graph, subject, predicate, blank_uri, error);
+			tracker_data_insert_statement (graph, subject, predicate, blank_uri, &actual_error);
 
 			g_hash_table_remove (blank_buffer.table, object);
 
+			if (actual_error) {
+				g_propagate_error (error, actual_error);
+				return;
+			}
+
 			return;
 		} else {
 			g_critical ("Blank node '%s' not found", object);
 		}
 	}
 
-	if (!tracker_data_insert_statement_common (graph, subject, predicate, object)) {
+	if (!tracker_data_insert_statement_common (graph, subject, predicate, object, &actual_error)) {
+		if (actual_error) {
+			g_propagate_error (error, actual_error);
+			return;
+		}
+
 		return;
 	}
 
@@ -1447,7 +1490,7 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 			cache_create_service_decomposed (class, graph);
 		} else {
 			g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_UNKNOWN_CLASS,
-				     "Class '%s' not found in the ontology", object);
+			             "Class '%s' not found in the ontology", object);
 		}
 	} else if (strcmp (predicate, TRACKER_PREFIX "uri") == 0) {
 		/* internal property tracker:uri, used to change uri of existing element */
@@ -1467,8 +1510,8 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 				TrackerStatementDelegate *delegate;
 
 				delegate = g_ptr_array_index (insert_callbacks, n);
-				delegate->callback (graph, subject, predicate, object, 
-				                    resource_buffer->types, 
+				delegate->callback (graph, subject, predicate, object,
+				                    resource_buffer->types,
 				                    delegate->user_data);
 			}
 		}
@@ -1501,7 +1544,12 @@ tracker_data_insert_statement_with_string (const gchar            *graph,
 		return;
 	}
 
-	if (!tracker_data_insert_statement_common (graph, subject, predicate, object)) {
+	if (!tracker_data_insert_statement_common (graph, subject, predicate, object, &actual_error)) {
+		if (actual_error) {
+			g_propagate_error (error, actual_error);
+			return;
+		}
+
 		return;
 	}
 
@@ -1519,9 +1567,9 @@ tracker_data_insert_statement_with_string (const gchar            *graph,
 			TrackerStatementDelegate *delegate;
 
 			delegate = g_ptr_array_index (insert_callbacks, n);
-			delegate->callback (graph, subject, predicate, object, 
-					    resource_buffer->types, 
-					    delegate->user_data);
+			delegate->callback (graph, subject, predicate, object,
+			                    resource_buffer->types,
+			                    delegate->user_data);
 		}
 	}
 }
@@ -1546,7 +1594,7 @@ void
 tracker_data_update_enable_volume (const gchar *udi,
                                    const gchar *mount_path)
 {
-	gchar		   *removable_device_urn;
+	gchar              *removable_device_urn;
 	gchar *delete_q;
 	gchar *set_q;
 	gchar *mount_path_uri;
@@ -1563,10 +1611,10 @@ tracker_data_update_enable_volume (const gchar *udi,
 	mount_path_file = g_file_new_for_path (mount_path);
 	mount_path_uri = g_file_get_uri (mount_path_file);
 
-	delete_q = g_strdup_printf ("DELETE { <%s> tracker:mountPoint ?d } WHERE { <%s> tracker:mountPoint ?d }", 
-				    removable_device_urn, removable_device_urn);
-	set_q = g_strdup_printf ("INSERT { <%s> a tracker:Volume; tracker:mountPoint <%s> }", 
-				 removable_device_urn, mount_path_uri);
+	delete_q = g_strdup_printf ("DELETE FROM <%s> { <%s> tracker:mountPoint ?d } WHERE { <%s> tracker:mountPoint ?d }",
+	                            removable_device_urn, removable_device_urn, removable_device_urn);
+	set_q = g_strdup_printf ("INSERT INTO <%s> { <%s> a tracker:Volume; tracker:mountPoint <%s> }",
+	                         removable_device_urn, removable_device_urn, mount_path_uri);
 
 	tracker_data_update_sparql (delete_q, &error);
 
@@ -1586,10 +1634,10 @@ tracker_data_update_enable_volume (const gchar *udi,
 	g_free (set_q);
 	g_free (delete_q);
 
-	delete_q = g_strdup_printf ("DELETE { <%s> tracker:isMounted ?d } WHERE { <%s> tracker:isMounted ?d }", 
-				    removable_device_urn, removable_device_urn);
-	set_q = g_strdup_printf ("INSERT { <%s> a tracker:Volume; tracker:isMounted true }", 
-				 removable_device_urn);
+	delete_q = g_strdup_printf ("DELETE FROM <%s> { <%s> tracker:isMounted ?d } WHERE { <%s> tracker:isMounted ?d }",
+	                            removable_device_urn, removable_device_urn, removable_device_urn);
+	set_q = g_strdup_printf ("INSERT INTO <%s> { <%s> a tracker:Volume; tracker:isMounted true }",
+	                         removable_device_urn, removable_device_urn);
 
 	tracker_data_update_sparql (delete_q, &error);
 
@@ -1625,9 +1673,10 @@ tracker_data_update_reset_volume (const gchar *uri)
 
 	mnow = time (NULL);
 	now_as_string = tracker_date_to_string (mnow);
-	delete_q = g_strdup_printf ("DELETE { <%s> tracker:unmountDate ?d } WHERE { <%s> tracker:unmountDate ?d }", uri, uri);
-	set_q = g_strdup_printf ("INSERT { <%s> a tracker:Volume; tracker:unmountDate \"%s\" }", 
-				 uri, now_as_string);
+	delete_q = g_strdup_printf ("DELETE FROM <%s> { <%s> tracker:unmountDate ?d } WHERE { <%s> tracker:unmountDate ?d }",
+	                            uri, uri, uri);
+	set_q = g_strdup_printf ("INSERT INTO <%s> { <%s> a tracker:Volume; tracker:unmountDate \"%s\" }",
+	                         uri, uri, now_as_string);
 
 	tracker_data_update_sparql (delete_q, &error);
 
@@ -1665,10 +1714,10 @@ tracker_data_update_disable_volume (const gchar *udi)
 
 	tracker_data_update_reset_volume (removable_device_urn);
 
-	delete_q = g_strdup_printf ("DELETE { <%s> tracker:isMounted ?d } WHERE { <%s> tracker:isMounted ?d }", 
-				    removable_device_urn, removable_device_urn);
-	set_q = g_strdup_printf ("INSERT { <%s> a tracker:Volume; tracker:isMounted false }", 
-				 removable_device_urn);
+	delete_q = g_strdup_printf ("DELETE FROM <%s> { <%s> tracker:isMounted ?d } WHERE { <%s> tracker:isMounted ?d }",
+	                            removable_device_urn, removable_device_urn, removable_device_urn);
+	set_q = g_strdup_printf ("INSERT INTO <%s> { <%s> a tracker:Volume; tracker:isMounted false }",
+	                         removable_device_urn, removable_device_urn);
 
 	tracker_data_update_sparql (delete_q, &error);
 
@@ -1702,19 +1751,22 @@ tracker_data_update_disable_all_volumes (void)
 	iface = tracker_db_manager_get_db_interface ();
 
 	stmt = tracker_db_interface_create_statement (iface,
-		"UPDATE \"rdfs:Resource\" SET Available = 0 "
-		"WHERE ID IN ("
-			"SELECT ID FROM \"nie:DataObject\" "
-			"WHERE \"nie:dataSource\" IN ("
-				"SELECT ID FROM \"rdfs:Resource\" WHERE Uri != ?"
-			")"
-		")");
+	                                              "UPDATE \"rdfs:Resource\" SET Available = 0 "
+	                                              "WHERE ID IN ("
+	                                              "SELECT ID FROM \"nie:DataObject\" "
+	                                              "WHERE \"nie:dataSource\" IN ("
+	                                              "SELECT ID FROM \"rdfs:Resource\" WHERE Uri != ?"
+	                                              ")"
+	                                              ")");
 	tracker_db_statement_bind_text (stmt, 0, TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN);
 	tracker_db_statement_execute (stmt, NULL);
 	g_object_unref (stmt);
 
-	delete_q = g_strdup_printf ("DELETE { ?o tracker:isMounted ?d } WHERE { ?o tracker:isMounted ?d  FILTER (?o != <"TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN"> ) }");
-	set_q = g_strdup_printf ("INSERT { ?o a tracker:Volume; tracker:isMounted false } WHERE { ?o a tracker:Volume FILTER (?o != <"TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN"> ) }");
+	/* The INTO and FROM uris are not really right, but it should be harmless:
+	 * we just want graph to be != NULL in tracker-store/tracker-writeback.c */
+
+	delete_q = g_strdup_printf ("DELETE FROM <"TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN"> { ?o tracker:isMounted ?d } WHERE { ?o tracker:isMounted ?d  FILTER (?o != <"TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN"> ) }");
+	set_q = g_strdup_printf ("INSERT INTO <"TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN"> { ?o a tracker:Volume; tracker:isMounted false } WHERE { ?o a tracker:Volume FILTER (?o != <"TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN"> ) }");
 
 	tracker_data_update_sparql (delete_q, &error);
 
@@ -1818,19 +1870,20 @@ format_sql_value_as_string (GString         *sql,
  * annotations (non-embedded/user metadata) stored about the resource.
  */
 void
-tracker_data_delete_resource_description (const gchar *graph, 
-                                          const gchar *uri, 
+tracker_data_delete_resource_description (const gchar *graph,
+                                          const gchar *uri,
                                           GError **error)
 {
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
 	TrackerDBResultSet *result_set, *single_result, *multi_result;
-	TrackerClass	   *class;
-	GString		   *sql;
-	TrackerProperty	  **properties, **property;
-	int		    i;
+	TrackerClass       *class;
+	GString                    *sql;
+	TrackerProperty           **properties, *property;
+	int                 i;
 	gboolean            first, bail_out = FALSE;
 	gint                resource_id;
+	guint               p, n_props;
 
 	/* We use result_sets instead of cursors here because it's possible
 	 * that otherwise the query of the outer cursor would be reused by the
@@ -1840,7 +1893,7 @@ tracker_data_delete_resource_description (const gchar *graph,
 
 	iface = tracker_db_manager_get_db_interface ();
 
-	properties = tracker_ontology_get_properties ();
+	properties = tracker_ontology_get_properties (&n_props);
 
 	stmt = tracker_db_interface_create_statement (iface, "SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdf:type\") FROM \"rdfs:Resource_rdf:type\" WHERE ID = ?");
 	tracker_db_statement_bind_int (stmt, 0, resource_id);
@@ -1867,19 +1920,22 @@ tracker_data_delete_resource_description (const gchar *graph,
 			sql = g_string_new ("SELECT ");
 
 			first = TRUE;
-			for (property = properties; *property; property++) {
-				if (tracker_property_get_domain (*property) == class) {
-					if (!tracker_property_get_embedded (*property)) {
+
+			for (p = 0; p < n_props; p++) {
+				property = properties[p];
+
+				if (tracker_property_get_domain (property) == class) {
+					if (!tracker_property_get_embedded (property)) {
 						continue;
 					}
 
-					if (!tracker_property_get_multiple_values (*property)) {
+					if (!tracker_property_get_multiple_values (property)) {
 						if (!first) {
 							g_string_append (sql, ", ");
 						}
 						first = FALSE;
 
-						format_sql_value_as_string (sql, *property);
+						format_sql_value_as_string (sql, property);
 					}
 				}
 			}
@@ -1896,21 +1952,23 @@ tracker_data_delete_resource_description (const gchar *graph,
 			g_string_free (sql, TRUE);
 
 			i = 0;
-			for (property = properties; *property; property++) {
-				if (tracker_property_get_domain (*property) != class) {
+			for (p = 0; p < n_props; p++) {
+				property = properties[p];
+
+				if (tracker_property_get_domain (property) != class) {
 					continue;
 				}
 
-				if (!tracker_property_get_embedded (*property)) {
+				if (!tracker_property_get_embedded (property)) {
 					continue;
 				}
 
-				if (strcmp (tracker_property_get_uri (*property), RDF_PREFIX "type") == 0) {
+				if (strcmp (tracker_property_get_uri (property), RDF_PREFIX "type") == 0) {
 					/* Do not delete rdf:type statements */
 					continue;
 				}
 
-				if (!tracker_property_get_multiple_values (*property)) {
+				if (!tracker_property_get_multiple_values (property)) {
 					gchar *value;
 					GError *new_error = NULL;
 
@@ -1919,10 +1977,9 @@ tracker_data_delete_resource_description (const gchar *graph,
 					tracker_db_result_set_get (single_result, i++, &value, -1);
 
 					if (value) {
-						
-						tracker_data_delete_statement (graph, uri, 
-						                               tracker_property_get_uri (*property), 
-						                               value, 
+						tracker_data_delete_statement (graph, uri,
+						                               tracker_property_get_uri (property),
+						                               value,
 						                               &new_error);
 						if (new_error) {
 							g_propagate_error (error, new_error);
@@ -1936,12 +1993,12 @@ tracker_data_delete_resource_description (const gchar *graph,
 
 					sql = g_string_new ("SELECT ");
 
-					format_sql_value_as_string (sql, *property);
+					format_sql_value_as_string (sql, property);
 
 					g_string_append_printf (sql,
-								" FROM \"%s_%s\" WHERE ID = ?",
-								tracker_class_get_name (tracker_property_get_domain (*property)),
-								tracker_property_get_name (*property));
+					                        " FROM \"%s_%s\" WHERE ID = ?",
+					                        tracker_class_get_name (tracker_property_get_domain (property)),
+					                        tracker_property_get_name (property));
 
 					stmt = tracker_db_interface_create_statement (iface, "%s", sql->str);
 					tracker_db_statement_bind_int (stmt, 0, resource_id);
@@ -1955,8 +2012,8 @@ tracker_data_delete_resource_description (const gchar *graph,
 
 							tracker_db_result_set_get (multi_result, 0, &value, -1);
 
-							tracker_data_delete_statement (graph, uri, 
-							                               tracker_property_get_uri (*property), 
+							tracker_data_delete_statement (graph, uri,
+							                               tracker_property_get_uri (property),
 							                               value,
 							                               &new_error);
 
@@ -1990,8 +2047,9 @@ tracker_data_delete_resource_description (const gchar *graph,
 
 void
 tracker_data_update_sparql (const gchar  *update,
-			    GError      **error)
+                            GError      **error)
 {
+	GError *actual_error = NULL;
 	TrackerDBInterface *iface;
 	TrackerSparqlQuery *sparql_query;
 
@@ -2003,9 +2061,9 @@ tracker_data_update_sparql (const gchar  *update,
 
 	tracker_db_interface_execute_query (iface, NULL, "SAVEPOINT sparql");
 
-	tracker_sparql_query_execute (sparql_query, error);
+	tracker_sparql_query_execute_update (sparql_query, FALSE, &actual_error);
 
-	if (*error) {
+	if (actual_error) {
 		tracker_data_update_buffer_clear ();
 		tracker_db_interface_execute_query (iface, NULL, "ROLLBACK TO sparql");
 
@@ -2017,6 +2075,11 @@ tracker_data_update_sparql (const gchar  *update,
 				delegate->callback (delegate->user_data);
 			}
 		}
+
+		g_propagate_error (error, actual_error);
+
+		g_object_unref (sparql_query);
+		return;
 	}
 
 	tracker_db_interface_execute_query (iface, NULL, "RELEASE sparql");
@@ -2024,3 +2087,49 @@ tracker_data_update_sparql (const gchar  *update,
 	g_object_unref (sparql_query);
 }
 
+
+GPtrArray *
+tracker_data_update_sparql_blank (const gchar  *update,
+                                  GError      **error)
+{
+	GError *actual_error = NULL;
+	TrackerDBInterface *iface;
+	TrackerSparqlQuery *sparql_query;
+	GPtrArray *blank_nodes;
+
+	g_return_val_if_fail (update != NULL, NULL);
+
+	iface = tracker_db_manager_get_db_interface ();
+
+	sparql_query = tracker_sparql_query_new_update (update);
+
+	tracker_db_interface_execute_query (iface, NULL, "SAVEPOINT sparql");
+
+	blank_nodes = tracker_sparql_query_execute_update (sparql_query, TRUE, &actual_error);
+
+	if (actual_error) {
+		tracker_data_update_buffer_clear ();
+		tracker_db_interface_execute_query (iface, NULL, "ROLLBACK TO sparql");
+
+		if (rollback_callbacks) {
+			guint n;
+			for (n = 0; n < rollback_callbacks->len; n++) {
+				TrackerCommitDelegate *delegate;
+				delegate = g_ptr_array_index (rollback_callbacks, n);
+				delegate->callback (delegate->user_data);
+			}
+		}
+
+		g_propagate_error (error, actual_error);
+
+		g_object_unref (sparql_query);
+		return NULL;
+	}
+
+	tracker_db_interface_execute_query (iface, NULL, "RELEASE sparql");
+
+	g_object_unref (sparql_query);
+
+	return blank_nodes;
+}
+
